@@ -1,10 +1,11 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
+
 ### BEGIN LICENSE
 # Copyright (C) 2010 Sebastian MacDonald Sebas310@gmail.com
 # Copyright (C) 2010 Mehdi Rejraji mehd36@gmail.com
 # Copyright (C) 2011 Vadim Rutkovsky roignac@gmail.com
-# Copyright (C) 2013 National University of Defense Technology(NUDT) & Kylin Ltd
+# Copyright (C) 2013 ~ 2014 National University of Defense Technology(NUDT) & Kylin Ltd
 # Authors: Zhang Zhao vaguedream@hotmail.com
 #          Kobe Lee kobe24_lixiang@126.com
 #          wyan yiwuhehe@163.com
@@ -35,7 +36,6 @@ import traceback
 import types
 import time
 import string
-from xml.dom.minidom import parseString
 import pycwapi
 import forecastui
 from helpers import *
@@ -155,6 +155,7 @@ class indicator_weather(threading.Thread):
         self.icon = None
         self.menu = None
         self.place = None
+        self.currentCity = None
         self.pm = {}
         self.places = str(self.settings.get_value("places"))
         self.placechosen = self.settings.get_value("placechosen")
@@ -348,6 +349,8 @@ class indicator_weather(threading.Thread):
             loco1 = gtk.RadioMenuItem(None, self.places[0][1])
             if self.placechosen == 0:
                 loco1.set_active(True)
+                # added by kobe 20140212
+                self.currentCity = self.places[0][1]
             loco1.connect("toggled", self.on_city_changed)
             loco1.show()
             self.menu.append(loco1)
@@ -356,6 +359,8 @@ class indicator_weather(threading.Thread):
                 loco = gtk.RadioMenuItem(loco1, place[1])
                 if self.places.index(place) == self.placechosen:
                     loco.set_active(True)
+                    # added by kobe 20140212
+                    self.currentCity = place[1]
                 loco.connect("toggled", self.on_city_changed)
                 loco.show()
                 self.menu.append(loco)
@@ -363,7 +368,7 @@ class indicator_weather(threading.Thread):
             breaker.show()
             self.menu.append(breaker)
 
-        ext_show = gtk.MenuItem(_("天气预报"))
+        ext_show = gtk.MenuItem(_("六天天气预报"))
         ext_show.connect("activate", self.forecast)
         ext_show.show()
         self.menu.append(ext_show)    
@@ -543,7 +548,7 @@ class indicator_weather(threading.Thread):
             self.aboutdialog = gtk.AboutDialog()
             self.aboutdialog.set_name(_("Indicator China Weather"))
             self.aboutdialog.set_version(VERSION)
-            self.aboutdialog.set_copyright('Copyright (C) 2013 UbuntuKylin Team kobe24_lixiang@126.com')
+            self.aboutdialog.set_copyright('Copyright (C) 2013 ~ 2014 UbuntuKylin Team xiangli@ubuntukylin.com')
 
             self.aboutdialog.set_comments(_('天气插件：提供来自于中国气象局的六天天气预报信息，添加\n人们日益关注的PM2.5指数，支持多城市切换和数据自动更新,\n分享每日生活指数和建议，为用户日常起居和旅行提供参考。'))
 
@@ -579,6 +584,8 @@ class indicator_weather(threading.Thread):
             gobject.timeout_add(360 * 60000, self.only_update_pm25)
 
     def forecast(self, widget):
+        # added by kobe 20140212
+        self.forecast_data['city'] = self.currentCity
         self.forecastwd = forecastui.ExtendedForecast(self.forecast_data)
 
 class PreferencesDialog(gtk.Dialog):
@@ -782,18 +789,27 @@ class Assistant(gtk.Assistant):
         else:
             iw.city_change_flag = False
         iw.city_id = self.cityid
-        iw.place = [self.cityid,self.context]
-        iw.settings.set_value("city_id", self.cityid)
 
-        if iw.places not in (False, None, '', '[]', "['']") and iw.place in iw.places and iw.prefswindow.builder.get_object('citieslist').get_iter_first() != None:
-            iw.placechosen = iw.places.index(iw.place)
+        # --------added 20140211 by kobe--------
+        flag = False
+        for placeitem in iw.places:
+            if placeitem[0] == iw.city_id:
+                flag = True
+                break
+        if flag:
+            flag = False
         else:
-            newplace = list()
-            newplace.append(self.context)#Label
-            newplace.append(self.cityid)#City
-            newplace.append(self.cityid)#details
-            item = iw.prefswindow.builder.get_object('citieslist').get_iter_first()
-            iw.prefswindow.builder.get_object('citieslist').append(newplace)
+            iw.place = [self.cityid,self.context]
+            iw.settings.set_value("city_id", self.cityid)
+            if iw.places not in (False, None, '', '[]', "['']") and iw.place in iw.places and iw.prefswindow.builder.get_object('citieslist').get_iter_first() != None:
+                iw.placechosen = iw.places.index(iw.place)
+            else:
+                newplace = list()
+                newplace.append(self.context)#Label
+                newplace.append(self.cityid)#City
+                newplace.append(self.cityid)#details
+                item = iw.prefswindow.builder.get_object('citieslist').get_iter_first()
+                iw.prefswindow.builder.get_object('citieslist').append(newplace)
 
         # Enable 'OK' button in Preferences
         iw.prefswindow.builder.get_object('ok_button').set_sensitive(True)
@@ -847,6 +863,11 @@ if __name__ == "__main__":
     if not cachedir:
         cachedir = os.path.expanduser("~/.cache")
     log_filename = os.path.join(cachedir, "indicator-china-weather.log")
+    if os.path.exists(log_filename):
+        #os.remove(log_filename)
+        print 'Log file exists...'
+    else:
+        print 'Log file does not exists...'
     log = logging.getLogger('IndicatorChinaWeather')
     log.propagate = False
     log.setLevel(logging.DEBUG)
